==> nextcloud-31.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/twofactor_totp/l10n/pt_BR.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Você habilitou a autenticação TOTP  dois fatores  para sua conta",
    "You disabled TOTP two-factor authentication for your account" : "Você desabilitou a autenticação TOTP dois fatores para sua conta",
    "TOTP (Authenticator app)" : "TOTP (Aplicativo autenticador)",
    "Authenticate with a TOTP app" : "Autenticar com um aplicativo TOTP",
    "Two-Factor TOTP Provider" : "Provedor TOTP de dois fatores",
    "Could not enable TOTP" : "Não foi  possível ativar o TOTP",
    "Could not verify your key. Please try again" : "Não foi possível verificar sua chave. Tente novamente.",
    "Enable TOTP" : "Ativar TOTP",
    "Your new TOTP secret is:" : "A nova senha TOTP is:",
    "For quick setup, scan this QR code with your TOTP app:" : "Para uma configuração rápida, digitalize este código QR com o seu aplicativo TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Após configurar seu aplicativo, insira um código de teste abaixo para garantir que tudo funcione corretamente:",
    "Authentication code" : "Código de autenticação",
    "Verify" : "Verificar",
    "Get the authentication code from the two-factor authentication app on your device." : "Obtenha o código de autenticação do aplicativo de autenticação de dois fatores em seu dispositivo.",
    "Submit" : "Enviar",
    "TOTP two-factor authentication disabled by an admin" : "A autenticação de dois fatores TOTP foi desativada por um administrador",
    "TOTP two-factor provider" : "Provedor de dois fatores TOTP",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Um provedor de dois fatores-autenticação para o TOTP (RFC 6238)"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/twofactor_totp/l10n/pt_BR.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Você habilitou a autenticação TOTP  dois fatores  para sua conta",
    "You disabled TOTP two-factor authentication for your account" : "Você desabilitou a autenticação TOTP dois fatores para sua conta",
    "TOTP two-factor authentication disabled by the administration" : "Autenticação de dois fatores TOTP desativada pela administração",
    "TOTP (Authenticator app)" : "TOTP (Aplicativo autenticador)",
    "Authenticate with a TOTP app" : "Autenticar com um aplicativo TOTP",
    "Two-Factor TOTP Provider" : "Provedor TOTP de dois fatores",
    "Two-factor TOTP provider" : "Provedor de TOTP de dois fatores",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "Um provedor de autenticação de dois fatores para TOTP (RFC 6238)",
    "Could not enable TOTP" : "Não foi  possível ativar o TOTP",
    "Could not verify your key. Please try again" : "Não foi possível verificar sua chave. Tente novamente.",
    "Enable TOTP" : "Ativar TOTP",
    "Your new TOTP secret is:" : "A nova senha TOTP is:",
    "For quick setup, scan this QR code with your TOTP app:" : "Para uma configuração rápida, escaneie este código QR com o seu aplicativo TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Após configurar seu aplicativo, insira um código de teste abaixo para garantir que tudo funcione corretamente:",
    "Authentication code" : "Código de autenticação",
    "Verify" : "Verificar",
    "Get the authentication code from the two-factor authentication app on your device." : "Obtenha o código de autenticação do aplicativo de autenticação de dois fatores em seu dispositivo.",
    "Submit" : "Enviar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
